#!/bin/bash

GLOBAL_SAVE_IFS="$IFS"
IFS='
'


function DlgShow()
{
    osascript -e "tell app \"System Events\" to display dialog \"$1\"  buttons {\"OK\"} default button 1 with title \"Recording plugin installation failed\" with icon caution"
}

if [ $UID != 0 ]
then
  DlgShow "$(whoami) is not root."
  exit 1
fi

tccutil reset AppleEvents

sudo echo ""

MYDIR=$(dirname "$0")
sudo sxattr -rc "${MYDIR}"

echo "\033[32m Round 1  \033[0m"
echo "ls -all ${MYDIR}"
ls -al@ "${MYDIR}"
echo "\n"

# Copy dirver into place
DRIVER_NAME="Audiojingle.driver"
DRIVER_INSTALL_PATH="/Library/Audio/Plug-Ins/HAL/${DRIVER_NAME}"
LAUNCHD_PLIST_INSTALL_PATH_1=/Library/LaunchDaemons
LAUNCHD_PLIST_INSTALL_PATH_2=/Library/LaunchAgents
LAUNCHD_PLIST_ID=com.audiojinglex.soundtree.agent
LAUNCHD_PLIST_FILENAME=${LAUNCHD_PLIST_ID}.plist
COREAUDIOD_PLIST="/System/Library/LaunchDaemons/com.apple.audio.coreaudiod.plist"

DST_LAUNCHD_PLIST_1="${LAUNCHD_PLIST_INSTALL_PATH_1}/${LAUNCHD_PLIST_FILENAME}"
DST_LAUNCHD_PLIST_2="${LAUNCHD_PLIST_INSTALL_PATH_2}/${LAUNCHD_PLIST_FILENAME}"
DST_LAUNCHD_PLIST_LAST=${DST_LAUNCHD_PLIST_1}


sudo /bin/mkdir -p /Library/Audio/Plug-Ins/HAL/

SRC_SRC_DRIVER_PATH=$1
SRC_LAUNCHD_PLIST=$2

if [ -z $1 ]; then
 SRC_DRIVER_PATH=${MYDIR}/${DRIVER_NAME}
fi

if [ -z $2 ]; then
  SRC_LAUNCHD_PLIST="${MYDIR}/${LAUNCHD_PLIST_FILENAME}"
fi

if [ ! -d "${SRC_DRIVER_PATH}" ]; then
    echo "${SRC_DRIVER_PATH} is not exist"
    DlgShow "${SRC_DRIVER_PATH} is not exist"
    exit 1
fi



if [ -d "${DRIVER_INSTALL_PATH}" ]; then
  sudo /bin/chmod 0777 "${DRIVER_INSTALL_PATH}"
  sudo /bin/rm -rf "${DRIVER_INSTALL_PATH}"
	if [ "$?" != "0" ]; then
    DlgShow "err:rm ${DRIVER_INSTALL_PATH}"
    exit 1
	fi
fi


sudo /usr/bin/ditto "${SRC_DRIVER_PATH}" "${DRIVER_INSTALL_PATH}"
if [ "$?" != "0" ]; then
  sudo /usr/bin/tar xvf "${SRC_DRIVER_PATH}.tar" -C /
  if [ "$?" != "0" ]; then
		sudo /usr/bin/ditto "${SRC_DRIVER_PATH}" "${DRIVER_INSTALL_PATH}"
	  if [ "$?" != "0" ]; then
	  	DlgShow "err:ditto ${SRC_DRIVER_PATH} ${DRIVER_INSTALL_PATH}"
	  	exit 1
		fi
	fi
fi
	
sudo /usr/sbin/chown -R root:wheel "/Library/Audio/Plug-Ins/HAL/${DRIVER_NAME}"
if [ "$?" != "0" ]; then
  DlgShow "err:chown -R root:wheel"
  exit 1
fi

echo "Install ${SRC_DRIVER_PATH} to ${DRIVER_INSTALL_PATH}."

echo "Install ${DRIVER_PATH} to ${DRIVER_INSTALL_PATH}."
echo "\033[32m @1111111111@->install->driver \033[0m"
echo "ls -al@ /Library/Audio/Plug-Ins/HAL/"
ls -al@ /Library/Audio/Plug-Ins/HAL/
echo "\033[32m @1111111111@->install->driver->Audiojingle \033[0m"
ls -al@ /Library/Audio/Plug-Ins/HAL/Audiojingle.driver/Contents/MacOS/Audiojingle


# Copy the plist template into place.
if [ -e "${DST_LAUNCHD_PLIST_1}" ]; then
    sudo /bin/chmod 0777 "${DST_LAUNCHD_PLIST_1}"
    sudo /bin/rm -f "${DST_LAUNCHD_PLIST_1}"
fi

sudo /usr/bin/xattr -c "${SRC_LAUNCHD_PLIST}"

sudo /usr/bin/ditto  "${SRC_LAUNCHD_PLIST}" "${DST_LAUNCHD_PLIST_1}"


if [ -e "${DST_LAUNCHD_PLIST_2}" ]; then
    sudo /bin/chmod 0777 "${DST_LAUNCHD_PLIST_2}"
    sudo /bin/rm -f "${DST_LAUNCHD_PLIST_2}"
fi

sudo /usr/bin/ditto  "${SRC_LAUNCHD_PLIST}" "${DST_LAUNCHD_PLIST_2}"

if [ ! -e "${DST_LAUNCHD_PLIST_1}" ]; then
    DST_LAUNCHD_PLIST_LAST=${DST_LAUNCHD_PLIST_2}
fi

if [ ! -e "${DST_LAUNCHD_PLIST_LAST}" ]; then
  DlgShow "err: both plists do not exist."
  exit 2
fi

# Set the plist's owner and permissions. (Probably not necessary, but just in case.)
sudo /usr/sbin/chown root:wheel "${DST_LAUNCHD_PLIST_LAST}"
sudo /bin/chmod 0644 "${DST_LAUNCHD_PLIST_LAST}"

echo "Installed ${LAUNCHD_PLIST_FILENAME} to ${DST_LAUNCHD_PLIST_LAST}."

# Unregister the plist. This disables the existing version of XPCHelper.

sudo /bin/launchctl bootout system "${DST_LAUNCHD_PLIST_LAST}" || \
sudo /bin/launchctl unbootstrap system "${DST_LAUNCHD_PLIST_LAST}" || \
sudo /bin/launchctl unload "${DST_LAUNCHD_PLIST_LAST}" || \
    true

# Register the plist with launchd. This enables XPCHelper.
# The fallback version of this command is for OS X 10.9.
sudo /bin/launchctl bootstrap system "${DST_LAUNCHD_PLIST_LAST}" || \
sudo /bin/launchctl load "${DST_LAUNCHD_PLIST_LAST}"

if [ "$?" != "0" ]; then
  DlgShow "err: Register the plist with launchd. This enables XPCHelper."
  exit 1
fi


echo "list launchd service."
sudo /bin/launchctl list | grep "${LAUNCHD_PLIST_ID}"


# The extra or-clauses are fallback versions of the command that restarts coreaudiod. Apparently
# some of these commands don't work with older versions of launchctl, so I figure there's no
# harm in trying a bunch of different ways (which should all work).
(sudo launchctl kickstart -k system/com.apple.audio.coreaudiod &>/dev/null || \
    sudo launchctl kill SIGTERM system/com.apple.audio.coreaudiod &>/dev/null || \
    sudo launchctl kill TERM system/com.apple.audio.coreaudiod &>/dev/null || \
    sudo launchctl kill 15 system/com.apple.audio.coreaudiod &>/dev/null || \
    sudo launchctl kill -15 system/com.apple.audio.coreaudiod &>/dev/null || \
    (sudo launchctl unload "${COREAUDIOD_PLIST}" &>/dev/null && \
        sudo launchctl load "${COREAUDIOD_PLIST}" &>/dev/null) || \
    sudo killall coreaudiod &>/dev/null) && \
    sleep 5

#sudo /usr/sbin/system_profiler  SPAudioDataType

echo "restart coreaudio"

IFS="$GLOBAL_SAVE_IFS"

exit 0
